Query class
Query class
Constructors
Properties
- collection → String
-
Collection
final
-
fieldValues
→ List<
FieldValue> ? -
Field Values
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
Id
final
- obj → dynamic
-
Object
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
Type
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - To Map
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited